<?php

/**
 * @package     Joomla.Plugin
 * @subpackage  System.accessibility
 *
 * @copyright   (C) 2020 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Joomla\Plugin\System\SeoPlugin\Extension;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\Uri\AbstractUri;
use Joomla\Event\DispatcherInterface;
use Joomla\Event\Priority;
use Joomla\Event\SubscriberInterface;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * System plugin to add additional accessibility features to the administrator interface.
 *
 * @since  4.0.0
 */
final class SeoPlugin extends CMSPlugin implements SubscriberInterface
{
    public function __construct(
        DispatcherInterface $dispatcher,
        private readonly AbstractUri $uri,
    ) {
        parent::__construct($dispatcher);

    }

    public function onBeforeCompileHead(): void
    {
        $this->loadLanguage();

        $this->setMetaTags();

        $this->setRedirects();

    }

    private function setMetaTags(): void
    {
        if (!$this->uri->getQuery()) {
            return;
        }
            $document = $this->getApplication()?->getDocument();
            $headData = $document->getHeadData();
            $headData['metaTags']['name']['robots'] = 'noindex, nofollow';
            $document->setHeadData($headData);
    }

    private function setRedirects(): void
    {
        if ($this->uri->getPath() === '/index.php') {
            $this->getApplication()->redirect('/', 301);
        }
    }

    public static function getSubscribedEvents(): array
    {
        return [
            'onBeforeCompileHead' => ['onBeforeCompileHead', Priority::NORMAL],
        ];
    }

}
